#
# spec file for package ghc-cereal
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name cereal
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.5.8.3
Release:        2.15
Summary:        A binary serialization library
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-array-devel
BuildRequires:  ghc-array-prof
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-rpm-macros
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-QuickCheck-prof
BuildRequires:  ghc-test-framework-devel
BuildRequires:  ghc-test-framework-prof
BuildRequires:  ghc-test-framework-quickcheck2-devel
BuildRequires:  ghc-test-framework-quickcheck2-prof
%endif

%description
A binary serialization library, similar to binary, that introduces an isolate
primitive for parser isolation, and labeled blocks for better error messages.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Tue Aug  9 2022 Peter Simons <psimons@suse.com>
- Update cereal to version 0.5.8.3.
  0.5.8.3
  =======
  * GHC 9.4.1 compatibility
* Sat May 28 2022 Peter Simons <psimons@suse.com>
- Update cereal to version 0.5.8.2 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Nov  4 2021 psimons@suse.com
- Update cereal to version 0.5.8.2.
  Upstream has not updated the file "CHANGELOG.md" since the last
  release.
* Thu Oct 14 2021 psimons@suse.com
- Update cereal to version 0.5.8.1 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Sat Jun  1 2019 psimons@suse.com
- Update cereal to version 0.5.8.1.
  0.5.8.1
  =======
  * GHC 8.8.1 compatibility
* Tue Jan  8 2019 psimons@suse.com
- Update cereal to version 0.5.8.0.
  0.5.8.0
  =======
  * Added ShortByteString instances
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Fri Aug 17 2018 psimons@suse.com
- Update cereal to version 0.5.7.0.
  0.5.7.0
  =======
  * Added `runPutMBuilder`
  0.5.6.0
  =======
  * Added GSerializeGet and GSerializePut instances for V1
  0.5.5.0
  =======
  * Added Semigroup instances
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Mon May 14 2018 psimons@suse.com
- Update cereal to version 0.5.5.0.
  Upstream does not provide a changelog.
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Mon Nov 14 2016 psimons@suse.com
- Update to version 0.5.4.0 with cabal2obs.
* Thu Sep 15 2016 psimons@suse.com
- Update to version 0.5.3.0 revision 0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.5.2.0 revision 0 with cabal2obs.
  This update obsoletes ghc-cereal-rpmlintrc.
* Wed Jun  1 2016 mimi.vx@gmail.com
- update to 0.5.2.0
  * Implement the AMP recommended refactoring for the Functor/Applicative/Monad
    hierarchy for Get and PutM
  * Unconditionally support GHC generics
  * Split the GSerialize class in two, to deal with a GHC bug
  * No longer use Enum in the Serialize instance for Bool
* Tue Jan 26 2016 mimi.vx@gmail.com
- update to 0.5.1.0
  * Switch to using the builder provided by the ByteString package
  * Change the encoding of Float and Double with the Serialize class to use the
    Data.Serialize.IEEE754 module
  * Add support for encoding and decoding ShortByteString
  * New and improved test suite thanks to Kei Hibino
  * Fix two bugs involving the lookAhead combinator and partial chunks.
* Tue Apr 21 2015 mimi.vx@gmail.com
- update to 0.4.1.1
  * no upstream changelog
* Sun Nov 23 2014 mimi.vx@gmail.com
- update to version 0.4.10
- move rpmlintrc to ghc-cereal.rpmlintrc
* Mon Oct 28 2013 sbahling@suse.com
- Update spec to cabalrpm template
* Thu Jun  7 2012 herbert@graeber-clan.de
- update to version 0.3.5.2
  spec file template generated by cabal2spec-0.25.5
* Sat Jan 21 2012 herbert@graeber-clan.de
- initial packaging for Fedora automatically generated by cabal2spec-0.24.1
